/*

 Copyright (C) 2011 Sun Ruping <ruping@molgen.mpg.de>

 This file is part of Breakpointer.

 Delve is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License.

*/

#include <cstdio>
#include <getopt.h>
#include <cstdlib>
#include <cstring>

struct parameters {
  char* region_f;
  char* mapping_f;
  char* qual_clip;
  unsigned int unique;
  char* mistag;
  unsigned int readlen;
};

struct parameters* interface(struct parameters* param,int argc, char *argv[]);
void delete_param(struct parameters* param);
void usage(void);

const char* program_name;

struct parameters* interface(struct parameters* param, int argc, char *argv[]){

  program_name = argv[0];
  int c;     // the next argument
  int help = 0;

  if (argc < 2){
    usage();
    exit(0);
  }

  param = new struct parameters;
  param->region_f  = new char;
  param->mapping_f = new char;
  param->qual_clip = new char;
  param->mistag    = new char;

  const struct option long_options[] ={
    {"region",1,0, 'r'},
    {"mapping",1,0,'m'},
    {"unique",0,0,'u'},
    {"readlen",1,0,'l'},
    {"qualclip",1,0,'q'},
    {"mistag",1,0,'e'},
    {"help",0,0,'h'},
    {0, 0, 0, 0}
  };


  while (1){

    int option_index = 0;
    c = getopt_long_only (argc, argv,"hur:m:l:q:e:",long_options, &option_index);

    if (c == -1){
      break;
    }

    switch(c) {
    case 0:
      break;
    case 'r':
      param->region_f = optarg;
      break;
    case 'm':
      param->mapping_f = optarg;
      break;
    case 'u':
      param->unique = 1;
      break;
    case 'e':
      param->mistag = optarg;
      break;
    case 'l':
      param->readlen = atoi(optarg);
      break;
    case 'q':
      param->qual_clip = optarg;
      break;
    case 'h':
      help = 1;
      break;
    case '?':
      help = 1;
      break;
    default:
      help = 1;
      break;
    }
  }

  if(help){
    usage();
    delete_param(param);
    exit(0);
  }

  return param;
}

void usage()
{
  fprintf(stdout, "\nbreakmis (mismatch screening) BreakPointer v0.1, 2011 Sun Ruping <ruping@molgen.mpg.de>\n");
  fprintf(stdout, "\n");
  fprintf(stdout, "Usage: %s options <argument needed> >output(gff format) \n\n", program_name);
  fprintf(stdout, "-r --region     <string> A region file generated by breakpointer.\n");
  fprintf(stdout, "-m --mapping    <string> A BAM alignment file or a file containing the filenames of multiple BAM files (one file per line). MUST be according to the chromosome and start position.\n                         In case of multiple BAM files, make sure these BAM files are sorted samely (require header tag: \"@HD\tVN:1.0\tSO:coordinate\").\n");
  fprintf(stdout, "-l --readlen    <int>    Length of the read (currently only support fixed length).\n");
  fprintf(stdout, "-q --qualclip   <string> Quality type for clipping (phred33,solexa64,phred64,no), default is Phred33, if \"no\", clipping is turned off.\n");
  fprintf(stdout, "-u --unique              take only uniquelly mapped reads (default: take all mapped reads). \n                         since different mappers generate different tags for uniqueness, if -q is set, user shoule provide unique tag info (see tag/val_uniq). \n                         we recommand not to set this option if the mapping file only contain a few multiple location reads, in case users are not sure about the unique tags.\n");
  fprintf(stdout, "-e --mistag     <string> The tag in the bam file denotating the mismatch string.\n");
  fprintf(stdout, "-h --help                Print the help message\n");
  fprintf(stdout, "\n");
}


void delete_param(struct parameters* param)
{
  delete(param->region_f);
  delete(param->mapping_f);
  delete(param->qual_clip);
  delete(param->mistag);
  delete(param);
}
